@@ -61,29 +61,6 @@ def add_entries(session):
     return True
 
 
-def add_details(session):
-    """
-    Add some random detail
-    """
-    # find the first entry
-    e1 = api.find_entry(session, title="Dummy 1")[0]
-    e2 = api.find_entry(session, title="Dummy 2")[0]
-
-    # check compability of < v0.1.8 api
-    api.add_details_to_entries(session, [e1], **{'foo': 'bar 1'})
-    api.add_details_to_entries(session, [e2], **{'foo': 'bar 2'})
-    api.add_details_to_entries(session, [e1, e2], **{'banana': 'both love it'})
-    
-    # check the new possibilites:
-    api.add_details_to_entries(session, [e1], 
-        details=[dict(key='baz', value=42, description='Baz is the best kw')])
-
-    d = e1.details_dict(full=True)
-    assert d['baz']['description']=='Baz is the best kw'
-    
-    return True
-
-
 def associate_persons(session):
     """
     Set the others as associated persons
@@ -267,6 +244,66 @@ def check_find_person(session):
     return True
 
 
+def add_details(session):
+    """
+    Add some random detail
+    """
+    # find the first entry
+    e1 = api.find_entry(session, title="Dummy 1")[0]
+    e2 = api.find_entry(session, title="Dummy 2")[0]
+
+    # check compability of < v0.1.8 api
+    api.add_details_to_entries(session, [e1], **{'foo': 'bar 1'})
+    api.add_details_to_entries(session, [e1, e2], **{'banana': 'both love it'})
+    
+    # check the new possibilites:
+    api.add_details_to_entries(session, [e1], 
+        details=[dict(key='baz', value=42, description='Baz is the best kw')])
+
+     # add nested details
+    e2.add_details(
+        foo=dict(bar=['list', 'of', 'strings'], baz=42),
+        answer=42,
+        commit=True
+    )
+
+    # get the table
+    e2.details_table(fmt='markdown')
+
+    # find the details
+    found_entry = api.find_entry(session, details=dict(answer=42))[0]
+    assert e2.id == found_entry.id
+
+    # find nested details
+    found_entry2 = api.find_entry(session, details=dict(foo=dict(baz=42)))[0]
+    assert e2.id == found_entry2.id
+
+    return True
+
+
+def mutate_details(session):
+    """
+    Check detail mutability
+    """
+    # get the same entry as before
+    e2 = api.find_entry(session, title="Dummy 2")[0]
+    detail = [d for d in e2.details if d.key == 'answer'][0]
+
+    # store detail id and check current value
+    detail_id = detail.id
+    assert detail.value == 42
+
+    # update
+    detail.value = 1312
+    session.add(e2)
+    session.commit()
+
+    # reload from database
+    updated = session.query(models.Detail).filter(models.Detail.id == detail_id).one()
+    assert detail.value == 1312
+    return True
+
+
 @pytest.mark.depends(on=['db_init'], name='add_find')
 def test_add_and_find():
     """
@@ -280,6 +317,7 @@ def test_add_and_find():
     assert add_person(session)
     assert add_entries(session)
     assert add_details(session)
+    assert mutate_details(session)
     assert associate_persons(session)
     assert check_related_information(session)
     assert check_find_with_wildcard(session)
